pub fn safe_parse_bytes(bytes: &[u8]) -> SafeOutcomeExpand description
Parse JSON bytes and fold every outcome into a SafeOutcome.
The byte counterpart to safe_parse. A leading UTF-8 byte order mark is
stripped before parsing.
pub fn safe_parse_bytes(bytes: &[u8]) -> SafeOutcomeParse JSON bytes and fold every outcome into a SafeOutcome.
The byte counterpart to safe_parse. A leading UTF-8 byte order mark is
stripped before parsing.